# coding=utf8
from optparse import make_option

__author__ = 'dreipol GmbH'

from django.core.management.base import BaseCommand, CommandError
import os
import subprocess
import re

regex = re.compile(
    u'(?P<cert>-----BEGIN CERTIFICATE-----.*-----END CERTIFICATE-----).*(?P<key>-----BEGIN RSA PRIVATE KEY-----.*-----END RSA PRIVATE KEY-----)',
    re.IGNORECASE | re.MULTILINE | re.UNICODE | re.DOTALL)


class Command(BaseCommand):
    option_list = BaseCommand.option_list + (
        make_option('-f', '--file',
                    action='store',
                    dest='file',
                    type="string",
                    help='The APNS .p12 file',

        ),
        make_option('-p', '--password',
                    action='store',
                    dest='password',
                    type="string",
                    help='The associated password',
        ),
         make_option('-e', '--encoding',
                    action='store',
                    dest='encoding',
                    type="string",
                    help='The used encoding',
                    default = 'utf-8'
        ),
    )
    help = 'Extracts the private key and ssl certificate from an APNS p12 file'

    def handle(self, *args, **options):
        file_name = options['file']
        password = options['password']
        encoding = options.get('encoding')
        if not (file_name and password):
            raise CommandError(u'Please specify a file and a password')

        if not os.path.isfile(file_name):
            raise CommandError(u'File "%s" does not exist'.format(file_name))
        arguments = "openssl pkcs12 -nodes -in {file} -passin pass:\"{pw}\"".format(file=file_name, pw=password)
        result = subprocess.check_output(arguments, shell=True).decode(encoding=encoding)
        groups = re.search(regex, result).groupdict()
        cert_string = groups["cert"].replace("\n", "\\n")
        key_string = groups["key"].replace("\n", "\\n")
        self.stdout.write("Copy the following two lines to your settings file:\n\n")
        self.stdout.write("SCARFACE_APNS_CERTIFICATE=\"{0}\"".format(cert_string))
        self.stdout.write("SCARFACE_APNS_PRIVATE_KEY=\"{0}\"".format(key_string))


# -*- coding: utf-8 -*-
from __future__ import unicode_literals

from django.db import models, migrations


class Migration(migrations.Migration):

    dependencies = [
    ]

    operations = [
        migrations.CreateModel(
            name='PushMessage',
            fields=[
                ('id', models.AutoField(verbose_name='ID', serialize=False, auto_created=True, primary_key=True)),
                ('sound', models.TextField(null=True, blank=True)),
                ('message', models.TextField(default=b'', null=True)),
                ('has_new_content', models.BooleanField(default=False)),
                ('context_id', models.TextField(default=b'none', null=True)),
                ('context', models.TextField(default=b'default', null=True)),
                ('badge_count', models.SmallIntegerField(default=0)),
                ('extra_payload', models.TextField(null=True, blank=True)),
                ('receiver_arn', models.TextField(null=True, blank=True)),
                ('message_type', models.PositiveSmallIntegerField(default=0)),
            ],
        ),
    ]


# -*- coding: utf-8 -*-
from django.apps import AppConfig as BaseAppConfig
__author__ = 'janmeier'

class AppConfig(BaseAppConfig):
    name = 'scarface'
    verbose_name ='Scarface'

    def ready(self):
        from . import signals
